@@ -16,21 +16,21 @@ import logging
 import os
 import warnings
 from collections import defaultdict
+from collections.abc import Collection, Iterator
 from pathlib import Path
-from typing import Collection, Iterator, NamedTuple, Optional, Type
+from typing import NamedTuple
 
 import attrs
-from binaryornot.check import is_binary
 
-from . import ReuseInfo
 from ._licenses import EXCEPTION_MAP, LICENSE_MAP
 from ._util import _determine_license_path, relative_from_root
+from .copyright import ReuseInfo, SourceType
 from .covered_files import iter_files
 from .exceptions import (
     GlobalLicensingConflictError,
     SpdxIdentifierNotFoundError,
 )
-from .extract import _LICENSEREF_PATTERN, reuse_info_of_file
+from .extract import _LICENSEREF_PATTERN, CHUNK_SIZE, reuse_info_of_file
 from .global_licensing import (
     GlobalLicensing,
     NestedReuseTOML,
@@ -47,7 +47,7 @@ _LOGGER = logging.getLogger(__name__)
 
 class GlobalLicensingFound(NamedTuple):
     path: Path
-    cls: Type[GlobalLicensing]
+    cls: type[GlobalLicensing]
 
 
 # TODO: The information (root, include_submodules, include_meson_subprojects,
@@ -64,7 +64,7 @@ class Project:
     include_submodules: bool = False
     include_meson_subprojects: bool = False
     vcs_strategy: VCSStrategy = attrs.field()
-    global_licensing: Optional[GlobalLicensing] = None
+    global_licensing: GlobalLicensing | None = None
 
     # TODO: I want to get rid of these, or somehow refactor this mess.
     license_map: dict[str, dict] = attrs.field()
@@ -125,7 +125,7 @@ class Project:
 
         vcs_strategy = cls._detect_vcs_strategy(root)
 
-        global_licensing: Optional[GlobalLicensing] = None
+        global_licensing: GlobalLicensing | None = None
         found = cls.find_global_licensing(
             root,
             include_submodules=include_submodules,
@@ -153,7 +153,7 @@ class Project:
 
         return project
 
-    def all_files(self, directory: Optional[StrPath] = None) -> Iterator[Path]:
+    def all_files(self, directory: StrPath | None = None) -> Iterator[Path]:
         """Yield all files in *directory* and its subdirectories.
 
         The files that are not yielded are those explicitly ignored by the REUSE
@@ -183,7 +183,7 @@ class Project:
         )
 
     def subset_files(
-        self, files: Collection[StrPath], directory: Optional[StrPath] = None
+        self, files: Collection[StrPath], directory: StrPath | None = None
     ) -> Iterator[Path]:
         """Like :meth:`all_files`, but all files that are not in *files* are
         filtered out.
@@ -229,11 +229,9 @@ class Project:
         An empty list is returned if no information was found whatsoever.
         """
         # pylint: disable=too-many-branches
-        original_path = path
+        original_path = Path(path)
         path = _determine_license_path(path)
 
-        _LOGGER.debug(f"searching '{path}' for REUSE information")
-
         # This means that only one 'source' of licensing/copyright information
         # is captured in ReuseInfo
         global_results: defaultdict[PrecedenceType, list[ReuseInfo]] = (
@@ -264,15 +262,20 @@ class Project:
                     " the file contents."
                 ).format(path=path)
             )
-        elif is_binary(str(path)):
-            _LOGGER.info(
-                _(
-                    "'{path}' was detected as a binary file; not searching its"
-                    " contents for REUSE information."
-                ).format(path=path)
-            )
         else:
-            file_result = reuse_info_of_file(path, original_path, self.root)
+            with path.open("rb", buffering=CHUNK_SIZE) as fp:
+                file_result = reuse_info_of_file(fp)
+            if file_result.contains_info():
+                source_type = SourceType.FILE_HEADER
+                if path.suffix == ".license":
+                    source_type = SourceType.DOT_LICENSE
+                file_result = file_result.copy(
+                    path=relative_from_root(
+                        original_path, self.root
+                    ).as_posix(),
+                    source_path=relative_from_root(path, self.root).as_posix(),
+                    source_type=source_type,
+                )
 
         result.extend(global_results[PrecedenceType.OVERRIDE])
         result.extend(global_results[PrecedenceType.AGGREGATE])
@@ -286,10 +289,10 @@ class Project:
             if global_results[PrecedenceType.CLOSEST]:
                 # There should only by a single CLOSEST result in the list.
                 closest = global_results[PrecedenceType.CLOSEST][0]
-                if file_result.copyright_lines:
+                if file_result.copyright_notices:
                     result.append(
                         closest.copy(
-                            copyright_lines=set(),
+                            copyright_notices=set(),
                         )
                     )
                 elif file_result.spdx_expressions:
@@ -300,7 +303,7 @@ class Project:
                     )
         return result
 
-    def relative_from_root(self, path: StrPath) -> Path:
+    def relative_from_root(self, path: Path) -> Path:
         """If the project root is /tmp/project, and *path* is
         /tmp/project/src/file, then return src/file.
         """
@@ -312,7 +315,7 @@ class Project:
         root: Path,
         include_submodules: bool = False,
         include_meson_subprojects: bool = False,
-        vcs_strategy: Optional[VCSStrategy] = None,
+        vcs_strategy: VCSStrategy | None = None,
     ) -> list[GlobalLicensingFound]:
         """Find the path and corresponding class of a project directory's
         :class:`GlobalLicensing`.
@@ -406,10 +409,7 @@ class Project:
             if Path(path).suffix == ".license":
                 continue
 
-            path = self.relative_from_root(path)
-            _LOGGER.debug(
-                _("determining identifier of '{path}'").format(path=path)
-            )
+            # path = self.relative_from_root(path)
 
             try:
                 identifier = self._identifier_of_license(path)
